<?php

namespace Drupal\owlcarousel\Commands;

use Drush\Commands\DrushCommands;
use Drupal\Core\File\FileSystemInterface;

class OwlCarouselCommands extends DrushCommands {

  /**
   * Downloads the OwlCarousel2 library to the libraries directory.
   *
   * @command owlcarousel:download
   * @aliases oc:dl
   * @usage owlcarousel:download
   *   Downloads the OwlCarousel2 library.
   */
  public function downloadOwlCarousel() {
    $url = 'https://github.com/OwlCarousel2/OwlCarousel2/archive/refs/tags/2.3.4.tar.gz';
    $libraries_path = DRUPAL_ROOT . '/libraries';
    $destination_folder = $libraries_path . '/owlcarousel2';

    // Ensure libraries directory exists.
    if (!file_exists($libraries_path)) {
      mkdir($libraries_path, 0777, TRUE);
      $this->output()->writeln('Created libraries directory.');
    }

    // Temp file path.
    $temp_file = tempnam(sys_get_temp_dir(), 'owlcarousel2') . '.tar.gz';

    // Download the file.
    file_put_contents($temp_file, file_get_contents($url));
    $this->output()->writeln('Downloaded OwlCarousel2 library.');

    // Extract the archive.
    $phar = new \PharData($temp_file);
    $phar->decompress(); // Create .tar

    $tar_path = str_replace('.gz', '', $temp_file);
    $phar_tar = new \PharData($tar_path);
    $phar_tar->extractTo($libraries_path, null, true);
    $this->output()->writeln('Extracted library.');

    // Rename extracted folder to 'tiny-slider'.
    $extracted_folder = $libraries_path . '/OwlCarousel2-2.3.4';
    if (file_exists($extracted_folder)) {
      if (file_exists($destination_folder)) {
        $this->output()->writeln('Removing old owlcarousel2 directory.');
        \Drupal::service('file_system')->deleteRecursive($destination_folder);
      }
      rename($extracted_folder, $destination_folder);
      $this->output()->writeln('Moved and renamed folder to owlcarousel2.');
    }

    // Clean up.
    unlink($temp_file);
    unlink($tar_path);

    $this->output()->writeln('wOlCarousel2 library successfully installed to libraries/owlcarousel2.');
  }
}
